@@ -1,6 +1,6 @@
 # -*-mode: tcl; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
-#       $Id: Plot3d.tcl,v 1.17 2009/11/30 04:37:06 villate Exp $
+#       $Id: Plot3d.tcl,v 1.19 2011/03/12 17:29:04 villate Exp $
 #
 ###### Plot3d.tcl ######
 ############################################################
@@ -21,7 +21,7 @@ set plot3dOptions {
     {bbox "" "xmin ymin xmax ymax zmin zmax overrides the -xcenter etc"}
     {zradius auto " Height in z direction of the z values"}
     {az 30 "azimuth angle" }
-    {el 60 "elevantion angle" }
+    {el 60 "elevation angle" }
 
     {thetax 10.0 "ignored is obsolete: use az and el"}
     {thetay 20.0 "ignored is obsolete: use az and el"}
@@ -671,13 +671,12 @@ The plot can be saved as a postscript file, by clicking on Save.
 } ] $Parser(help)]]
 }
 
-proc     makeFrame3d { win } {
+proc makeFrame3d { win } {
     global plot3dPoints
     set w [makeFrame $win 3d]
     set top $w
     catch { set top [winfo parent $w]}
     catch {
-
 	wm title $top [mc "Xmaxima: Plot3d"]
 	wm iconname $top "plot3d"
 	#   wm geometry $top 750x700-0+20
@@ -704,20 +703,14 @@ proc mkPlot3d { win  args } {
     makeLocal $win buttonFont c
     [winfo parent $c].position config -text {}
     bind $c <Motion> ""
-#   bind $c <Motion> "showPosition3d $win %x %y"
-    button $wb.rotate -text [mc "Rotate"] -command "setForRotate $win" -font $buttonFont
 #    setBalloonhelp $win $wb.rotate [mc {Dragging the mouse with the left button depressed will cause the object to rotate.  The rotation keeps the z axis displayed in an upright position (ie parallel to the sides of the screen), but changes the viewpoint.   Moving right and left changes the azimuth (rotation about the z axis), and up and down changes the elevation (inclination of z axis).   The red,blue and green sides of the bounding box are parallel to the X, Y and Z axes, and are on the smaller side.}]
 
     #$win.position config -width 15
-    pack $wb.rotate -side left
     setForRotate $win
 }
 
 proc doConfig3d { win } {
-
-
     desetq "wb1 wb2" [doConfig $win]
-
     makeLocal $win buttonFont
 
     mkentry $wb1.zfun [oloc $win zfun]  "z=f(x,y)" $buttonFont
