@@ -1,6 +1,6 @@
 # -*-mode: tcl; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
-#       $Id: xmaxima-trailer.tcl,v 1.12 2006/06/29 12:58:27 villate Exp $
+#       $Id: xmaxima-trailer.tcl,v 1.13 2011/03/09 11:31:23 villate Exp $
 #
 # Attach this at the bottom of the xmaxima code to start up the interface.
 
@@ -22,7 +22,7 @@ if { [llength $maxima_priv(plotfile)] > 0 } {
     regsub -all -- {[[:space:]]+} $inputdata { } inputdata
     string trim $inputdata
      if {[catch {eval $inputdata}]} {
-	 bgerror "Input file has syntax errors"
+	 bgerror [mc "Input file has syntax errors"]
 	 exit
      }
 } else {
