@@ -1,7 +1,7 @@
 ;;;
 ;;;  GRAPHS - graph theory package for Maxima
 ;;;
-;;;  Copyright (C) 2007-2008 Andrej Vodopivec <andrej.vodopivec@gmail.com>
+;;;  Copyright (C) 2007-2011 Andrej Vodopivec <andrej.vodopivec@gmail.com>
 ;;;
 ;;;  This program is free software; you can redistribute it and/or modify
 ;;;  it under the terms of the GNU General Public License as published by
@@ -32,8 +32,7 @@
 (defstruct (graph
 	     (:print-function
 	      (lambda (stru strm depth)
-		(declare (ignore stru))
-		(format strm "GRAPH"))))
+		(format strm "GRAPH(~a vertices, ~a edges)" (graph-order stru) (graph-size stru)))))
   (size 0)
   (order 0)
   (vertices ())
@@ -46,8 +45,7 @@
 (defstruct (digraph
 	     (:print-function
 	      (lambda (stru strm depth)
-		(declare (ignore stru))
-		(format strm "DIGRAPH"))))
+		(format strm "DIGRAPH(~a vertices, ~a arcs)" (digraph-order stru) (digraph-size stru)))))
   (size 0)
   (order 0)
   (vertices ())
@@ -125,8 +123,9 @@
 	    (if l (set-vertex-label v l g))))
 	(dolist (e (graph-edges gr))
 	  (add-edge e g)
-	  (let ((w (get-edge-weight e g)))
+	  (let ((w (get-edge-weight e gr)))
 	    (if w (set-edge-weight e w g))))
+        ($set_positions ($get_positions gr) g)
 	g)
       (let ((g (make-digraph)))
 	(dolist (v (digraph-vertices gr))
@@ -137,6 +136,7 @@
 	  (add-edge e g)
 	  (let ((w (get-edge-weight e g)))
 	    (if w (set-edge-weight e w g))))
+        ($set_positions ($get_positions gr) g)
 	g) ))
 
 (defmfun $get_positions (gr)
@@ -189,21 +189,30 @@
   (require-graph-or-digraph 'vertex_in_graph 2 gr)
   (is-vertex-in-graph i gr))
 
-(defmfun $add_vertex (i gr)
+(defmfun $add_vertex (i &optional gr)
+  (unless gr
+    (setq gr i)
+    (setq i (1+ (apply #'max (vertices gr)))))
   (require-vertex 'add_vertex 1 i)
   (require-graph-or-digraph 'add_vertex 2 gr)
   (when (is-vertex-in-graph i gr)
     ($error "add_vertex: vertex is already in the graph!"))
   (add-vertex i gr)
-  '$done)
+  i)
 
 (defmfun $add_vertices (vl gr)
   (require-graph-or-digraph 'add_vertices 2 gr)
-  (when (not ($listp vl))
+  (unless (or (integerp vl) ($listp vl))
     ($error "Argument 1 to add_vertices is not a list."))
-  (dolist (v (cdr vl))
-    ($add_vertex v gr))
-  '$done)
+  (if ($listp vl)
+      (dolist (v (cdr vl))
+        ($add_vertex v gr))
+      (let* ((n vl))
+        (setq vl ())
+        (dotimes (i n)
+          (setf vl (cons ($add_vertex gr) vl)))
+        (setf vl (cons '(mlist simp) (reverse vl)))))
+  vl)
 
 (defun add-vertex (i gr)
   (if (graph-p gr)
@@ -278,7 +287,10 @@
 	  (let ((e (list (min u v) (max u v))))
 	    (remove-edge e gr)))
 	(clear-vertex-label v gr)
-	(setf (graph-vertex-positions gr) nil)
+        (when (graph-vertex-positions gr)
+          (setf (graph-vertex-positions gr)
+                (cons '(mlist simp) (remove-if (lambda (x) (= (cadr x) v))
+                                               (cdr (graph-vertex-positions gr))))))
 	(setf (graph-vertices gr) (remove v (graph-vertices gr) :count 1))
 	(remhash v (graph-neighbors gr))
 	(decf (graph-order gr)))
@@ -288,7 +300,10 @@
 	(dolist (u (in-neighbors v gr))
 	  (remove-edge (list u v) gr))
 	(clear-vertex-label v gr)
-	(setf (digraph-vertex-positions gr) nil)
+        (when (digraph-vertex-positions gr)
+          (setf (digraph-vertex-positions gr)
+                (cons '(mlist simp) (remove-if (lambda (x) (= (cadr x) v))
+                                               (cdr (digraph-vertex-positions gr))))))
 	(setf (digraph-vertices gr) (remove v (digraph-vertices gr) :count 1))
 	(remhash v (digraph-in-neighbors gr))
 	(remhash v (digraph-out-neighbors gr))
@@ -350,11 +365,11 @@
   (require-vertex-in-graph 'vertex_out_degree v gr)
   (length (out-neighbors v gr)))
 
-(defmfun $get_vertex_label (v gr)
+(defmfun $get_vertex_label (v gr &optional default)
   (require-vertex 'get_vertex_label 1 v)
   (require-graph-or-digraph 'get_vertex_label 2 gr)
   (require-vertex-in-graph 'vertex_label v gr)
-  (get-vertex-label v gr))
+  (or (get-vertex-label v gr) default))
 
 (defun get-vertex-label (v gr)
   (gethash v  (if (graph-p gr)
@@ -545,17 +560,17 @@
     ($contract_edge e gr))
   '$done)
 
-(defmfun $get_edge_weight (e gr &optional default)
+(defmfun $get_edge_weight (e gr &optional default not-present)
   (require-medge 'get_edge_weight 1 e)
   (require-graph-or-digraph 'get_edge_weight 2 gr)
   (unless ($is_edge_in_graph e gr)
-    (if (null default)
+    (if (null not-present)
 	($error "get_edge_weight: edge not in graph")
-	(return-from $get_edge_weight default)))
+	(return-from $get_edge_weight not-present)))
   (let ((w (if (graph-p gr)
 	       (get-edge-weight (m-edge-to-l-edge e) gr)
 	       (get-edge-weight (m-edge-to-l-dedge e) gr))))
-    (or w 1)))
+    (or w default 1)))
 
 (defun get-edge-weight (e gr)
   (let* ((edge-weights
@@ -674,7 +689,7 @@
     gr))
 
 (defmfun $empty_digraph (n)
-  (let ((gr (make-digraph)))
+  (let ((gr (make-digraph)) (pos))
     (dotimes (i n)
       (add-vertex i gr))
     gr))
@@ -711,10 +726,15 @@
       gr)))
 
 (defmfun $cycle_graph (n)
-  (let ((g ($empty_graph n)))
+  (let ((g ($empty_graph n)) pos)
     (dotimes (i (1- n))
       (add-edge (list i (1+ i)) g))
     (add-edge (list 0 (1- n)) g)
+    (dotimes (i n)
+      (setq pos (cons `((mlist simp) ,i
+                        ((mlist simp) ,(cos (* i 2 pi (/ n))) ,(sin (* i 2 pi (/ n)))))
+                      pos)))
+    ($set_positions (cons '(mlist simp) pos) g)
     g))
 
 (defmfun $cycle_digraph (n)
@@ -725,9 +745,14 @@
     g))
 
 (defmfun $path_graph (n)
-  (let ((g ($empty_graph n)))
+  (let ((g ($empty_graph n)) pos)
     (dotimes (i (1- n))
       (add-edge (list i (1+ i)) g))
+    (dotimes (i n)
+      (setq pos (cons `((mlist simp) ,i
+                        ((mlist simp) ,i 0))
+                      pos)))
+    ($set_positions (cons '(mlist simp) pos) g)
     g))
 
 (defmfun $path_digraph (n)
@@ -754,14 +779,14 @@
 	(add-edge `(,e1 ,e2) g)))
     (dotimes (i n)
       (push `((mlist simp) ,i ((mlist simp)
-			       ,($sin (/ (* 2 i pi) n))
-			       ,($cos (/ (* 2 i pi) n))))
+			       ,(sin (/ (* 2 i pi) n))
+			       ,(cos (/ (* 2 i pi) n))))
 	    positions)
       (push `((mlist simp) ,(+ n i) ((mlist simp)
-				     ,(* 0.66 ($sin (/ (* 2 i pi) n)))
-				     ,(* 0.66 ($cos (/ (* 2 i pi) n)))))
+				     ,(* 0.66 (sin (/ (* 2 i pi) n)))
+				     ,(* 0.66 (cos (/ (* 2 i pi) n)))))
 	    positions))
-    ($set_positions (cons '(mlist simp) positions) g)
+    (setf (graph-vertex-positions g) (cons '(mlist simp) positions))
     g))
 
 (defmfun $complement_graph (gr)
@@ -781,12 +806,19 @@
 (defmfun $complete_graph (n)
   (if (not (and (integerp n ) (>= n 0)))
       ($error "Argument 1 to complete_graph is not a positive integer"))
-  (let ((g ($empty_graph n)))
+  (let ((g ($empty_graph n))
+        (pos))
     (dotimes (i n)
       (do
        ((j (1+ i) (1+ j)))
        ((= j n))
 	(add-edge `(,i ,j) g)))
+    (dotimes (i n)
+      (push `((mlist simp) ,i ((mlist simp)
+                               ,(cos (/ (* 2 i pi) n))
+                               ,(sin (/ (* 2 i pi) n))))
+            pos))
+    (setf (graph-vertex-positions g) (cons '(mlist simp) pos))
     g))
 
 (defmfun $from_adjacency_matrix (m)
@@ -1066,29 +1098,6 @@
     ($set_positions (cons '(mlist simp) positions) g)
     g))
 
-(defmfun $flower_snark (&optional (o 5))
-  (let ((g ($empty_graph (* 4 o))))
-    (labels
-	((make-edge (u v)
-	   (list (min u v) (max u v)))
-	 (a (i)
-	   (mod i o))
-	 (b (i)
-	   (+ o (mod i o)))
-	 (c (i)
-	   (+ o o (mod i o)))
-	 (d (i)
-	   (+ o o o (mod i o))))
-      (dotimes (i o)
-	(add-edge (make-edge (a i) (a (1+ i))) g)
-	(add-edge (make-edge (a i) (b i)) g)
-	(add-edge (make-edge (b i) (c i)) g)
-	(add-edge (make-edge (b i) (d i)) g)
-	(add-edge (make-edge (c i) (d (1+ i))) g)
-	(add-edge (make-edge (d i) (c (1+ i))) g) ))
-    g))
-
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; graph properties
@@ -1567,11 +1576,11 @@
 	(dolist (w (out-neighbors v net))
 	  (if (and (null (gethash w lbls))
 		   (mlsp (gethash `(,v ,w) flow)
-			 (get-edge-weight `(,v ,w) net)))
+			 (or (get-edge-weight `(,v ,w) net) 1)))
 	      (progn
 		(setf (gethash w d)
 		      (mfuncall '$min
-				(m- (get-edge-weight `(,v ,w) net)
+				(m- (or (get-edge-weight `(,v ,w) net) 1)
 				    (gethash `(,v ,w) flow))
 				(gethash v d)))
 		(setf (gethash w lbls) `(,v 1 ,(gethash w d)))
@@ -1726,37 +1735,53 @@
 (defvar *hamilton-cycle* ())
 
 (defmfun $hamilton_cycle (gr)
-  (require-graph-or-digraph 'hamilton_cycle 1 gr)
-  (if (and (graph-p gr) (not ($is_biconnected gr)))
+  (require-graph 'hamilton_cycle 1 gr)
+  (let (*hamilton-cycle* (*v0* ($first_vertex gr)))
+    (declare (special *v0*))
+    (unless ($is_biconnected gr)
       (return-from $hamilton_cycle `((mlist simp))))
-  (setq *hamilton-cycle* ())
-  (hamilton-cycle `(,($first_vertex gr)) gr)
-  `((mlist simp) ,@(reverse *hamilton-cycle*)))
+    (hamilton-cycle (list *v0*) gr)
+    `((mlist simp) ,@(reverse *hamilton-cycle*))))
 
 (defun hamilton-cycle (part gr)
-  (if (null *hamilton-cycle*)
-      (progn
-	(if (= (length part) (if (graph-p gr)
-				 (graph-order gr)
-				 (digraph-order gr)))
-	    (if (member (car (last part)) (neighbors (first part) gr))
-		(setq *hamilton-cycle* (append (last part) part))))
-	(dolist (v (neighbors (car part) gr))
-	  (if (null (member v part))
-	      (hamilton-cycle (cons v part) gr))))))
+  (declare (special *v0*))
+  (unless *hamilton-cycle*
+    (if (= (length part) (if (graph-p gr)
+                             (graph-order gr)
+                             (digraph-order gr)))
+        (if (member (car (last part)) (neighbors (first part) gr))
+            (setq *hamilton-cycle* (append (last part) part))))
+    (dolist (v (neighbors (car part) gr))
+      (when (null (member v part))
+        (if (< (length part) 3)
+            (hamilton-cycle (cons v part) gr)
+            (let ((gr1 ($copy_graph gr))
+                  (in-part (rest (reverse part))))
+              ($remove_vertices (cons '(mlist simp) in-part) gr1)
+              (unless (member v (neighbors *v0* gr))
+                ($add_edge `((mlist simp) ,v ,*v0*) gr1))
+              (when ($is_biconnected gr1)
+                (hamilton-cycle (cons v part) gr))))))))
 
 (defmfun $hamilton_path (gr)
-  (require-graph-or-digraph 'hamilton_path 1 gr)
-  (let ((h ($copy_graph gr))
-	(x (1+ (mfuncall #'$lmax `((mlist simp) ,@(vertices gr))))))
-    (add-vertex x h)
+  (require-graph 'hamilton_path 1 gr)
+  ;; first check if there exists a HC
+  (let ((hc ($hamilton_cycle gr)))
+    (when (cdr hc)
+      (return-from $hamilton_path ($rest hc))))
+  ;; check with all non-edges
+  (let ((grc ($complement_graph gr)))
     (dolist (v (vertices gr))
-      (add-edge `(,x ,v) h)
-      (if (digraph-p gr)
-	  (add-edge `(,v ,x) h)))
-    (setq *hamilton-cycle* ())
-    (hamilton-cycle `(,x) h)
-    `((mlist simp) ,@(remove x (reverse *hamilton-cycle*)))))
+      (dolist (u (neighbors v grc))
+        (when (< v u)
+          (let ((*v0* v)
+                (*hamilton-cycle*)
+                (part (list u v)))
+            (declare (special *v0*))
+            (hamilton-cycle part gr)
+            (when *hamilton-cycle*
+              (return-from $hamilton_path (cons '(mlist simp) (rest (reverse *hamilton-cycle*))))))))))
+  '((mlist simp)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -1796,7 +1821,10 @@
   (require-graph 'max_clique 1 gr)
   (setq *maximum-clique* ())
   (let ((v) (coloring) (h ($copy_graph gr)))
-    (do () ((>= (length *maximum-clique*) (graph-order h)))
+    (do () ((or (>= (length *maximum-clique*) (graph-order h))
+		(> (length *maximum-clique*) ($first ($max_degree h)))))
+;      (print *maximum-clique*)
+;      (print ($max_degree h))
       (setq coloring (greedy-color h))
       (setq v ($second ($max_degree h)))
       (extend-clique `(,v) (neighbors v h) coloring h)
