@@ -25,6 +25,8 @@
 ($put '$grcommon 1 '$version)
 
 
+(defvar $draw_use_pngcairo nil "If true, use pngcairo terminal when png is requested.")
+
 ;; This variable stores actual graphics options
 (defvar *gr-options* (make-hash-table))
 
@@ -67,10 +69,10 @@
       (gethash '$user_preamble *gr-options*)    ""
       (gethash '$xyplane *gr-options*)          nil
       (gethash '$font *gr-options*)             "";
-      (gethash '$font_size *gr-options*)        12;
+      (gethash '$font_size *gr-options*)        10;
 
       ; colors are specified by name
-      (gethash '$color *gr-options*)           "#000000" ; for lines, points, borders and labels
+      (gethash '$color *gr-options*)           "#0000ff" ; for lines, points, borders and labels
       (gethash '$fill_color *gr-options*)      "#ff0000" ; for filled regions
       (gethash '$fill_density *gr-options*)    0         ; in [0,1], only for object 'bars
 
@@ -132,6 +134,7 @@
 
       ; polygon  options
       (gethash '$transparent *gr-options*) nil
+      (gethash '$opacity *gr-options*)     1
       (gethash '$border *gr-options*)      t
 
       ; vector  options
@@ -186,7 +189,7 @@
 
 ;; update options color, fill_color, xaxis_color, yaxis_color,
 ;; $zaxis_color, and $background_color
-;; ------------------------------------------------------------------------
+;; -----------------------------------------------------------
 ;; defined as a color name or hexadecimal #rrggbb
 (defun atom-to-downcased-string (val)
    (substitute
@@ -329,7 +332,8 @@
 
 (defun update-terminal (val)
   (let ((terms '($screen $png $pngcairo $jpg $gif $eps $eps_color $svg
-                 $pdf $pdfcairo $wxt $animated_gif $aquaterm)))
+                 $pdf $pdfcairo $wxt $animated_gif $aquaterm
+                 $tiff $vrml $obj $pnm)))
      (cond
        ((member val terms)
           (when (and (eq val '$png) $draw_use_pngcairo)
@@ -490,8 +494,8 @@
 
 
 
-;; update boolean options
-;; ----------------------
+;; update boolean type options
+;; ---------------------------
 (defun update-boolean-option (opt val)
   (if (or (equal val t)
           (null val))
@@ -500,8 +504,8 @@
 
 
 
-;; update positive integer
-;; -----------------------
+;; update positive integer type options
+;; ------------------------------------
 (defun update-positive-integer (opt val)
   (if (and (integerp val)
            (> val 0 ))
@@ -510,8 +514,8 @@
 
 
 
-;; update positive float
-;; ---------------------
+;; update positive float type options
+;; ----------------------------------
 (defun update-positive-float (opt val)
   (setf val ($float val))
   (if (and (numberp val)
@@ -521,6 +525,17 @@
 
 
 
+;; update non negative float type options
+;; --------------------------------------
+(defun update-nonnegative-float (opt val)
+  (setf val ($float val))
+  (if (and (numberp val)
+           (>= val 0 ))
+      (setf (gethash opt *gr-options*) val)
+      (merror "draw: Not a non-negative number: ~M " val)))
+
+
+
 ;; update option: view
 ;; -------------------
 (defun update-view (val)
@@ -558,9 +573,122 @@
 
 
 
+;; update option point_type
+;; --------------------------
+(defun update-pointtype (val)
+  (cond
+    ((and (integerp val) (>= val -1 ))
+       (setf (gethash '$point_type *gr-options*) val))
+    (t (let ((shapes '($none $dot $plus $multiply $asterisk
+                       $square $filled_square $circle $filled_circle
+                       $up_triangle $filled_up_triangle $down_triangle
+                       $filled_down_triangle $diamant $filled_diamant
+                       $sphere $cube $cylinder $cone)))
+          (if (member val shapes)
+              (setf (gethash '$point_type *gr-options*) (- (position val shapes) 1))
+              (merror "draw: illegal point type: ~M " val)))))  )
 
 
 
+;; update string type options
+;; --------------------------
+(defun update-string (opt val)
+  (setf (gethash opt *gr-options*) val))
+
+
+
+;; update opacity option
+;; ---------------------
+(defun update-opacity (val)
+  (let ((value ($float val)))
+    (when (or (not (floatp value))
+              (> value 1)
+              (< value 0))
+      (merror "draw: illegal opacity value: ~M " val))
+    (setf (gethash '$opacity *gr-options*) value)))
+
+
+
+;; update palette option
+;; ---------------------
+
+(defun update-palette (val)
+  ; defined as $color, $gray, [f1,f2,f3], with -36<=fi<=36,
+  ; or a list of triplets defining a user palette.
+  (cond ((member val '($color $gray))
+          (setf (gethash '$palette *gr-options*) val))
+
+        ((and ($listp val)
+              (= ($length val) 3)
+              (every #'(lambda (x) (and (integerp x) (<= (abs x) 36)))
+                     (cdr val)) )
+          (setf (gethash '$palette *gr-options*) (rest val)))
+
+        ((and ($listp val)  ; user defined palette without transparency
+              (not ($listp (cadr val)) ))
+           (let* ((palette (cdr val))
+                  (n (length palette))
+                  str color)
+             (setf (gethash '$palette *gr-options*)
+                   (loop for k below n
+                      do (setf str (atom-to-downcased-string (nth k palette)))
+                         (cond ((correct-color-hex str)
+                                  (setf color (hex-to-numeric-list str)))
+                               ((correct-color-name str)
+                                  (setf color (hex-to-numeric-list (gethash str *color-table*))))
+                               (t
+                                  (merror "draw: illegal color in palette description")))
+                      collect color))))
+
+        ((and ($listp val)  ; user defined palette with transparency
+              (every #'(lambda (x) (and ($listp x) (= (length x) 3)))
+                     (cdr val)))
+           (let* ((palette (cdr val))
+                  (n (length palette))
+                  str color transparency)
+             (setf (gethash '$palette *gr-options*)
+                   (loop for k below n
+                      do (setf str (atom-to-downcased-string ($first (nth k palette))))
+                         (cond ((correct-color-hex str)
+                                  (setf color (hex-to-numeric-list str)))
+                               ((correct-color-name str)
+                                  (setf color (hex-to-numeric-list (gethash str *color-table*))))
+                               (t
+                                  (merror "draw: illegal color in palette description")))
+                         (setf transparency ($float ($second (nth k palette))))
+                         (when (or (< transparency 0)
+                                   (> transparency 1)
+                                   (not (floatp transparency)))
+                           (merror "draw: illegal transparency in palette description"))
+                      collect (append color (list transparency))))))
+
+        (t
+          (merror "draw: illegal palette description: ~M" val))) )
+
+
+
+;; update line_type and line-axes
+;; Negative indices indicate the number of faces to be drawn in case of tubes.
+;; Default number of faces is 8.
+;; --------------------------------------------------------------------------
+(defun update-linestyle (opt val)
+  (cond
+    ((atom val)
+       (case val
+         ($dots     (setf (gethash opt *gr-options*) 0))
+         ($solid    (setf (gethash opt *gr-options*) 1))
+         ($dashes   (setf (gethash opt *gr-options*) 2))
+         ($dot_dash (setf (gethash opt *gr-options*) 3))
+         ($tube     (setf (gethash opt *gr-options*) -8))
+         (otherwise  (merror "draw: illegal line type: ~M" val) )))
+    ((and ($listp val)
+          (= ($length val) 2)
+          (equal ($first val) '$tube)
+          (integerp ($second val))
+          (> ($second val) 2))
+       (setf (gethash opt *gr-options*) (- ($second val)) ) )
+    (t
+       (merror "draw: unknown line type: ~M" val))))
 
 
 
@@ -608,7 +736,7 @@
                      (<= val 1 ))
                 (setf (gethash opt *gr-options*) val)
                 (merror "draw: fill_density must be a number in [0, 1]")))
-      (($line_width $head_length $head_angle $xaxis_width $yaxis_width $zaxis_width)
+      (($line_width $head_length $head_angle $xaxis_width $yaxis_width $zaxis_width $font_size)
             (update-positive-float opt val))
       ($xyplane ; defined as real number or false
             (setf val ($float val))
@@ -617,11 +745,7 @@
                 (setf (gethash opt *gr-options*) val)
                 (merror "draw: illegal xyplane allocation: ~M " val)))
       ($point_size ; defined as non negative numbers
-            (setf val ($float val))
-            (if (and (numberp val)
-                     (>= val 0 ))
-                (setf (gethash opt *gr-options*) val)
-                (merror "draw: negative number: ~M " val)))
+        (update-nonnegative-float opt val))
       ($points_joined ; defined as true, false or $impulses
             (if (member val '(t nil $impulses))
               (setf (gethash opt *gr-options*) val)
@@ -632,10 +756,7 @@
               (setf (gethash opt *gr-options*) val)
               (merror "draw: illegal colorbox option: ~M " val)) )
       (($line_type $xaxis_type $yaxis_type $zaxis_type) ; defined as $solid or $dots
-            (case val
-               ($solid (setf (gethash opt *gr-options*) 1))
-               ($dots  (setf (gethash opt *gr-options*) 0))
-               (otherwise  (merror "draw: illegal line type: ~M" val))) )
+         (update-linestyle opt val) )
       (($tube_extremes) ; defined as a list of two elements, $open and/or $closed
             (if (and ($listp val)
                      (= ($length val) 2)
@@ -643,18 +764,9 @@
                      (member ($second val) '($open $closed)))
                (setf (gethash opt *gr-options*) val)
                (merror "draw: illegal tube extreme types: ~M" val)))
-      ($point_type ; numbers >= -1 or shape names
-            (cond
-              ((and (integerp val) (>= val -1 ))
-                 (setf (gethash opt *gr-options*) val))
-              (t (let ((shapes '($none $dot $plus $multiply $asterisk
-                                 $square $filled_square $circle $filled_circle
-                                 $up_triangle $filled_up_triangle $down_triangle
-                                 $filled_down_triangle $diamant $filled_diamant)))
-                    (if (member val shapes)
-                        (setf (gethash opt *gr-options*) (- (position val shapes) 1))
-                        (merror "draw: illegal point type: ~M " val))))) )
-      (($columns $nticks $adapt_depth $xu_grid $yv_grid $delay $x_voxel $y_voxel $z_voxel $font_size)
+      ($point_type
+         (update-pointtype val))
+      (($columns $nticks $adapt_depth $xu_grid $yv_grid $delay $x_voxel $y_voxel $z_voxel)
             (update-positive-integer opt val))
       ($contour_levels    ; positive integer, increment or set of points
             (cond ((and (integerp val) (> val 0 ))
@@ -676,6 +788,8 @@
                        (setf (gethash opt *gr-options*) (string-trim '(#\,) str) ) ))
                   (t
                     (merror "draw: unknown contour level description: ~M " val))))
+      ($opacity
+         (update-opacity val))
       (($transparent $border $logx $logy $logz $logcb $head_both $grid
         $xaxis_secondary $yaxis_secondary $axis_bottom $axis_left $axis_top
         $axis_right $axis_3d $surface_hide $xaxis $yaxis $zaxis $unit_vectors
@@ -763,8 +877,8 @@
                 (setf (gethash opt *gr-options*) val)
                 (merror "draw: illegal label orientation: ~M" val)))
       (($key $file_name $xy_file $title $xlabel $ylabel $zlabel $font
-        $gnuplot_file_name $data_file_name)  ; defined as strings
-            (setf (gethash opt *gr-options*) val))
+        $gnuplot_file_name $data_file_name)
+            (update-string opt val))
       ($user_preamble ; defined as a string or a Maxima list of strings
             (let ((str ""))
               (cond
@@ -805,16 +919,8 @@
                          (integerp ($second val))))
                (merror "draw: illegal value for grid")
                (setf (gethash opt *gr-options*) val))))
-      ($palette ; defined as $color, $gray or [f1,f2,f3], with -36<=fi<=36
-            (cond ((member val '($color $gray))
-                    (setf (gethash opt *gr-options*) val))
-                  ((and ($listp val)
-                        (= ($length val) 3)
-                        (every #'(lambda (x) (and (integerp x) (<= (abs x) 36)))
-                               (cdr val)) )
-                    (setf (gethash opt *gr-options*) (list (cadr val) (caddr val) (cadddr val))))
-                  (t
-                    (merror "draw: illegal palette description: ~M" val)))  )
+      ($palette
+        (update-palette val))
       (($color $fill_color $xaxis_color $yaxis_color
         $zaxis_color $background_color)
         (update-color opt val))
@@ -847,3 +953,149 @@
 
       (otherwise (merror "draw: unknown option ~M " opt))  ) )
 
+
+
+
+;;; COMMON GNUPLOT - VTK AUXILIARY FUNCTIONS
+
+;; Transforms arguments to make-scene-2d, make-scene-3d,
+;; draw, and vtk3d to a unique list. With this piece of code,
+;; gr2d, gr3d, draw, and model3d admit as arguments nested lists
+;; of options and graphic objects
+(defmacro listify-arguments ()
+   '(rest ($flatten
+             ($tree_reduce 
+               '$append
+               (cons '(mlist)
+                     (map 
+                       'list #'(lambda (z) (if ($listp z) z (list '(mlist) z)))
+                       args))))))
+
+
+
+
+
+;; The following functions implement the marching cubes algorithm
+;; for implicit functions in 3d.
+(simplify ($load "implicit3d.lisp"))
+
+; Copies multidimensional arrays.
+(defun copy-array (array)
+  (let ((dims (array-dimensions array)))
+    (adjust-array
+      (make-array
+         dims
+         :element-type (array-element-type array)
+         :displaced-to array)
+      dims)))
+
+; Calculates surface-edge intersection by interpolation
+(defun edge-interpolation (x1 y1 z1 x2 y2 z2 v1 v2)
+  (cond ((or (< (abs v1) 0.00001)
+             (< (abs (- v1 v2)) 0.00001))
+          (list x1 y1 z1))
+        ((< (abs v2) 0.00001)
+          (list x2 y2 z2))
+        (t
+          (let ((m (/ (- v1) (- v2 v1))))
+            (list
+              (+ x1 (* m (- x2 x1)))
+              (+ y1 (* m (- y2 y1)))
+              (+ z1 (* m (- z2 z1))))))))
+
+(defmacro make-triangle-vertices (i1 j1 k1 i2 j2 k2 e1 e2)
+  `(edge-interpolation
+       (aref px ,i1) (aref py ,j1) (aref pz ,k1)
+       (aref px ,i2) (aref py ,j2) (aref pz ,k2)
+       (aref val ,e1) (aref val ,e2)))
+
+(defun flatten (lis)
+  (cond ((atom lis) lis)
+        ((listp (car lis))
+          (append (flatten (car lis)) (flatten (cdr lis))))
+        (t
+          (append (list (car lis)) (flatten (cdr lis))))))
+
+(defun find-triangles (expr par1 xmin xmax par2 ymin ymax par3 zmin zmax)
+  (let* ((nx (get-option '$x_voxel))
+         (ny (get-option '$y_voxel))
+         (nz (get-option '$z_voxel))
+         (dx (/ (- xmax xmin) nx))
+         (dy (/ (- ymax ymin) ny))
+         (dz (/ (- zmax zmin) nz))
+         (fcn (coerce-float-fun (m- ($lhs expr) ($rhs expr)) `((mlist) ,par1 ,par2 ,par3)))
+         (vert '())
+         (px (make-array (+ nx 1) :element-type 'flonum))
+         (py (make-array (+ ny 1) :element-type 'flonum))
+         (pz (make-array (+ nz 1) :element-type 'flonum))
+         (oldval (make-array `(,(+ nx 1) ,(+ ny 1)) :element-type 'flonum))
+         (newval (make-array `(,(+ nx 1) ,(+ ny 1)) :element-type 'flonum))    )
+    ; initialize coordinate arrays
+    (loop for i to nx do (setf (aref px i) (+ xmin (* i dx))))
+    (loop for j to ny do (setf (aref py j) (+ ymin (* j dy))))
+    (loop for k to nz do (setf (aref pz k) (+ zmin (* k dz))))
+
+    ; initialize first layer
+    (loop for i to nx do
+      (loop for j to ny do
+        (let ((fxy (funcall fcn (aref px i) (aref py j) (aref pz 0))))
+          (if (floatp fxy)
+            (setf (aref oldval i j) fxy)
+            (merror "draw3d (implicit): non real value")))))
+
+    ; begin triangularization process
+    (loop for k from 1 to nz do
+
+      ; calculate node values in new layer
+      (loop for i to nx do
+        (loop for j to ny do
+          (let ((fxy (funcall fcn (aref px i) (aref py j) (aref pz k))))
+            (if (floatp fxy)
+              (setf (aref newval i j) fxy)
+              (merror "draw3d (implicit): check surface definition; non real value")))))
+
+      ; analyze voxels in this slide
+      (loop for i below nx do
+        (loop for j below ny do
+          (let* (triangles
+                 (cubidx 0)
+                 (k-1 (- k 1))
+                 (i+1 (+ i 1))
+                 (j+1 (+ j 1))
+                 (val (make-array 8 :element-type
+                                       'flonum
+                                    :initial-contents
+                                       `(,(aref oldval i j+1) ,(aref oldval i+1 j+1)
+                                         ,(aref oldval i+1 j) ,(aref oldval i j)
+                                         ,(aref newval i j+1) ,(aref newval i+1 j+1)
+                                         ,(aref newval i+1 j) ,(aref newval i j)))))
+            (when (< (aref val 0) 0.0) (setf cubidx (logior cubidx 1)))
+            (when (< (aref val 1) 0.0) (setf cubidx (logior cubidx 2)))
+            (when (< (aref val 2) 0.0) (setf cubidx (logior cubidx 4)))
+            (when (< (aref val 3) 0.0) (setf cubidx (logior cubidx 8)))
+            (when (< (aref val 4) 0.0) (setf cubidx (logior cubidx 16)))
+            (when (< (aref val 5) 0.0) (setf cubidx (logior cubidx 32)))
+            (when (< (aref val 6) 0.0) (setf cubidx (logior cubidx 64)))
+            (when (< (aref val 7) 0.0) (setf cubidx (logior cubidx 128)))
+            (setf triangles (aref *i3d_triangles* cubidx))   ; edges intersecting the surface
+            (do ((e 0 (1+ e)))
+                ((= (aref triangles e) -1) 'done)
+              (push 
+                (case (aref triangles e)
+                  (0  (make-triangle-vertices i j+1 k-1 i+1 j+1 k-1 0 1))
+                  (1  (make-triangle-vertices i+1 j+1 k-1 i+1 j k-1 1 2))
+                  (2  (make-triangle-vertices i+1 j k-1 i j k-1 2 3))
+                  (3  (make-triangle-vertices i j k-1 i j+1 k-1 3 0))
+                  (4  (make-triangle-vertices i j+1 k i+1 j+1 k 4 5))
+                  (5  (make-triangle-vertices i+1 j+1 k i+1 j k 5 6))
+                  (6  (make-triangle-vertices i+1 j k i j k 6 7))
+                  (7  (make-triangle-vertices i j k i j+1 k 7 4))
+                  (8  (make-triangle-vertices i j+1 k-1 i j+1 k 0 4))
+                  (9  (make-triangle-vertices i+1 j+1 k-1 i+1 j+1 k 1 5))
+                  (10 (make-triangle-vertices i+1 j k-1 i+1 j k 2 6))
+                  (11 (make-triangle-vertices i j k-1 i j k 3 7)) )
+                vert)))))
+      ; make oldval a copy of newval
+      (setf oldval (copy-array newval)))
+    vert))
+
