@@ -1,13 +1,13 @@
 ;;; Compiled by f2cl version:
-;;; ("f2cl1.l,v 1.212 2009/01/08 18:58:49 rtoy Exp $"
+;;; ("f2cl1.l,v 1.215 2009/04/07 22:05:21 rtoy Exp $"
 ;;;  "f2cl2.l,v 1.37 2008/02/22 22:19:33 rtoy Exp $"
 ;;;  "f2cl3.l,v 1.6 2008/02/22 22:19:33 rtoy Exp $"
 ;;;  "f2cl4.l,v 1.7 2008/02/22 22:19:34 rtoy Exp $"
-;;;  "f2cl5.l,v 1.199 2009/01/07 19:16:59 rtoy Exp $"
+;;;  "f2cl5.l,v 1.200 2009/01/19 02:38:17 rtoy Exp $"
 ;;;  "f2cl6.l,v 1.48 2008/08/24 00:56:27 rtoy Exp $"
 ;;;  "macros.l,v 1.112 2009/01/08 12:57:19 rtoy Exp $")
 
-;;; Using Lisp CMU Common Lisp Snapshot 2008-12 (19E)
+;;; Using Lisp CMU Common Lisp 19f (19F)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -531,12 +531,10 @@
                                              (wstart)
                                              ((1 *)))
                        iwork info)
-                    (declare (ignore var-0 var-3 var-4 var-5 var-6 var-7 var-8
-                                     var-9 var-10 var-11 var-12 var-13 var-14
-                                     var-15 var-16 var-17 var-18 var-19 var-20
-                                     var-21 var-22))
-                    (setf smlsiz var-1)
-                    (setf nsize var-2)
+                    (declare (ignore var-0 var-1 var-2 var-3 var-4 var-5 var-6
+                                     var-7 var-8 var-9 var-10 var-11 var-12
+                                     var-13 var-14 var-15 var-16 var-17 var-18
+                                     var-19 var-20 var-21 var-22))
                     (setf info var-23))
                   (cond
                     ((/= info 0)
