@@ -30,9 +30,40 @@
 (defmfun $airy_ai (z)
   "Airy function Ai(z)"
   (simplify (list '(%airy_ai) (resimplify z))))
+(defprop $airy_ai %airy_ai alias)
+(defprop $airy_ai %airy_ai verb)
+(defprop %airy_ai $airy_ai reversealias)
+(defprop %airy_ai $airy_ai noun)
 (defprop %airy_ai simp-%airy_ai operators)
 (defprop %airy_ai ((z) ((%airy_dai) z)) grad)
 
+;; Airy Ai function has mirror symmetry
+(defprop %airy_ai t commutes-with-conjugate)
+
+;; Integral of Ai(z)
+;; http://functions.wolfram.com/03.05.21.0002.01
+;; (z/(3^(2/3)*gamma(2/3)))*hypergeometric([1/3],[2/3,4/3],z^3/9)
+;; - (3^(1/6)/(4*%pi))*z^2*gamma(2/3)*hypergeometric([2/3],[4/3,5/3],z^3/9);
+(defprop %airy_ai
+  ((z)
+   ((mplus)
+    ((mtimes) 
+     ((mexpt) 3 ((rat) -2 3))
+     ((mexpt) ((%gamma) ((rat) 2 3)) -1)
+     (($hypergeometric) 
+      ((mlist) ((rat) 1 3))
+      ((mlist) ((rat) 2 3) ((rat) 4 3)) 
+      ((mtimes) ((rat) 1 9) ((mexpt) z 3)))
+     z)
+   ((mtimes) 
+    ((rat) -1 4) ((mexpt) 3 ((rat) 1 6)) ((mexpt) $%pi -1) ((%gamma) ((rat) 2 3))
+    (($hypergeometric) 
+     ((mlist) ((rat) 2 3)) 
+     ((mlist) ((rat)  4 3) ((rat) 5 3))
+     ((mtimes) ((rat) 1 9) ((mexpt) z 3)))
+    ((mexpt) z 2))))
+  integral)
+
 (defun airy-ai (z)
   (cond ((floatp z) (airy-ai-real z))
 	((complexp z) (airy-ai-complex z))))
@@ -43,7 +74,11 @@
   (declare (ignore unused))
   (oneargcheck form)
   (let ((z (simpcheck (cadr form) x)))
-    (cond ((flonum-eval (mop form) z))
+    (cond ((equal z 0) ; A&S 10.4.4: Ai(0) = 3^(-2/3)/gamma(2/3)
+	    '((mtimes simp)
+	      ((mexpt simp) 3 ((rat simp) -2 3))
+	      ((mexpt simp) ((%gamma simp) ((rat simp) 2 3)) -1)))
+	  ((flonum-eval (mop form) z))
 	  (t (eqtest (list '(%airy_ai) z) form)))))
 
 
@@ -51,8 +86,16 @@
 (defmfun $airy_dai (z)
   "Derivative dAi/dz of Airy function Ai(z)"
   (simplify (list '(%airy_dai) (resimplify z))))
+(defprop $airy_dai %airy_dai alias)
+(defprop $airy_dai %airy_dai verb)
+(defprop %airy_dai $airy_dai reversealias)
+(defprop %airy_dai $airy_dai noun)
 (defprop %airy_dai simp-%airy_dai operators)
 (defprop %airy_dai ((z) ((mtimes) z ((%airy_ai) z))) grad)
+(defprop %airy_dai ((z) ((%airy_ai) z)) integral)
+
+;; Airy Ai' function has mirror symmetry
+(defprop %airy_dai t commutes-with-conjugate)
 
 (defun airy-dai (z)
   (cond ((floatp z) (airy-dai-real z))
@@ -64,17 +107,51 @@
   (declare (ignore unused))
   (oneargcheck form)
   (let ((z (simpcheck (cadr form) x)))
-    (cond ((flonum-eval (mop form) z))
+    (cond ((equal z 0) ; A&S 10.4.5: Ai'(0) = -3^(-1/3)/gamma(1/3)
+          '((mtimes simp) -1
+	      ((mexpt simp) 3 ((rat simp) -1 3))
+	      ((mexpt simp) ((%gamma simp) ((rat simp) 1 3)) -1)))
+	  ((flonum-eval (mop form) z))
 	  (t (eqtest (list '(%airy_dai) z) form)))))
 
-
 ;; Airy Bi function 
 (defmfun $airy_bi (z)
   "Airy function Bi(z)"
   (simplify (list '(%airy_bi) (resimplify z))))
+(defprop $airy_bi %airy_bi alias)
+(defprop $airy_bi %airy_bi verb)
+(defprop %airy_bi $airy_bi reversealias)
+(defprop %airy_bi $airy_bi noun)
 (defprop %airy_bi simp-%airy_bi operators)
 (defprop %airy_bi ((z) ((%airy_dbi) z)) grad)
 
+;; Airy Bi function has mirror symmetry
+(defprop %airy_bi t commutes-with-conjugate)
+
+;; Integral of Bi(z)
+;; http://functions.wolfram.com/03.06.21.0002.01
+;; (z/(3^(1/6)*gamma(2/3)))*hypergeometric([1/3],[2/3,4/3],z^3/9)
+;; + (3^(2/3)/(4*%pi))*z^2*gamma(2/3)*hypergeometric([2/3],[4/3,5/3],z^3/9);
+(defprop %airy_bi
+  ((z)
+   ((mplus)
+    ((mtimes) 
+     ((mexpt) 3 ((rat) -1 6))
+     ((mexpt) ((%gamma) ((rat) 2 3)) -1)
+     (($hypergeometric) 
+      ((mlist) ((rat) 1 3))
+      ((mlist) ((rat) 2 3) ((rat) 4 3)) 
+      ((mtimes) ((rat) 1 9) ((mexpt) z 3)))
+     z)
+   ((mtimes) 
+    ((rat) 1 4) ((mexpt) 3 ((rat) 2 3)) ((mexpt) $%pi -1) ((%gamma) ((rat) 2 3))
+    (($hypergeometric) 
+     ((mlist) ((rat) 2 3)) 
+     ((mlist) ((rat)  4 3) ((rat) 5 3))
+     ((mtimes) ((rat) 1 9) ((mexpt) z 3)))
+    ((mexpt) z 2))))
+  integral)
+
 (defun airy-bi (z)
   (cond ((floatp z) (airy-bi-real z))
 	((complexp z) (airy-bi-complex z))))
@@ -85,16 +162,27 @@
   (declare (ignore unused))
   (oneargcheck form)
   (let ((z (simpcheck (cadr form) x)))
-    (cond ((flonum-eval (mop form) z))
+    (cond ((equal z 0) ; A&S 10.4.4: Bi(0) = sqrt(3) 3^(-2/3)/gamma(2/3)
+	    '((mtimes simp)
+	      ((mexpt simp) 3 ((rat simp) -1 6))
+	      ((mexpt simp) ((%gamma simp) ((rat simp) 2 3)) -1)))
+	  ((flonum-eval (mop form) z))
 	  (t (eqtest (list '(%airy_bi) z) form)))))
 
-
 ;; Derivative dBi/dz of Airy function Bi(z)
 (defmfun $airy_dbi (z)
   "Derivative dBi/dz of Airy function Bi(z)"
   (simplify (list '(%airy_dbi) (resimplify z))))
+(defprop $airy_dbi %airy_dbi alias)
+(defprop $airy_dbi %airy_dbi verb)
+(defprop %airy_dbi $airy_dbi reversealias)
+(defprop %airy_dbi $airy_dbi noun)
 (defprop %airy_dbi simp-%airy_dbi operators)
 (defprop %airy_dbi ((z) ((mtimes) z ((%airy_bi) z))) grad)
+(defprop %airy_dbi ((z) ((%airy_bi) z)) integral)
+
+;; Airy Bi' function has mirror symmetry
+(defprop %airy_dbi t commutes-with-conjugate)
 
 (defun airy-dbi (z)
   (cond ((floatp z) (airy-dbi-real z))
@@ -106,10 +194,13 @@
   (declare (ignore unused))
   (oneargcheck form)
   (let ((z (simpcheck (cadr form) x)))
-    (cond ((flonum-eval (mop form) z))
+    (cond ((equal z 0) ; A&S 10.4.5: Bi'(0) = sqrt(3) 3^(-1/3)/gamma(1/3)
+          '((mtimes simp) 
+	    ((mexpt simp) 3 ((rat simp) 1 6))
+	    ((mexpt simp) ((%gamma simp) ((rat simp) 1 3)) -1)))
+	  ((flonum-eval (mop form) z))
 	  (t (eqtest (list '(%airy_dbi) z) form)))))
 
-
 ;; Numerical routines using slatec functions
 
 (defun airy-ai-real (z)
@@ -187,7 +278,7 @@
         (declare (type flonum rz c))
         (multiple-value-bind (var-0 var-1 var-2 bi dbi)
 	    (slatec:dyairy z rz c 0.0 0.0)
-	  (declare (flonum bi dbi)
+	  (declare (type flonum bi dbi)
 		   (ignore var-0 var-1 var-2 bi))
 	  dbi))
       ;; Will overflow.  Return unevaluated.
