@@ -408,22 +408,22 @@ relational knowledge is contained in the default context GLOBAL.")
 	      (t `((mnot simp) ,arg)))
 	(let ((arg-op (caar arg)) (arg-arg (cdr arg)))
 	  ;;(setq arg-arg (mapcar #'(lambda (a) (maybe-simplifya a z)) arg-arg))
-	  (cond ((eq arg-op 'mlessp)
-		 (simplify `((mgeqp simp) ,@arg-arg)))
-		((eq arg-op 'mleqp)
-		 (simplify `((mgreaterp simp) ,@arg-arg)))
-		((eq arg-op 'mequal)
-		 (simplify `((mnotequal simp) ,@arg-arg)))
-		((eq arg-op '$equal)
-		 (simplify `(($notequal simp) ,@arg-arg)))
-		((eq arg-op 'mnotequal)
-		 (simplify `((mequal simp) ,@arg-arg)))
-		((eq arg-op '$notequal)
-		 (simplify `(($equal simp) ,@arg-arg)))
-		((eq arg-op 'mgeqp)
-		 (simplify `((mlessp simp) ,@arg-arg)))
-		((eq arg-op 'mgreaterp)
-		 (simplify `((mleqp simp) ,@arg-arg)))
+          (cond ((eq arg-op 'mlessp)
+                 (simplify `((mgeqp) ,@arg-arg)))
+                ((eq arg-op 'mleqp)
+                 (simplify `((mgreaterp) ,@arg-arg)))
+                ((eq arg-op 'mequal)
+                 (simplify `((mnotequal) ,@arg-arg)))
+                ((eq arg-op '$equal)
+                 (simplify `(($notequal) ,@arg-arg)))
+                ((eq arg-op 'mnotequal)
+                 (simplify `((mequal) ,@arg-arg)))
+                ((eq arg-op '$notequal)
+                 (simplify `(($equal) ,@arg-arg)))
+                ((eq arg-op 'mgeqp)
+                 (simplify `((mlessp) ,@arg-arg)))
+                ((eq arg-op 'mgreaterp)
+                 (simplify `((mleqp) ,@arg-arg)))
 		((eq arg-op 'mnot)
 		 (car arg-arg))
 		;; Distribute negation over conjunction and disjunction;
@@ -453,13 +453,20 @@ relational knowledge is contained in the default context GLOBAL.")
 (defun mevalp1 (pat)
   (let (patevalled ans)
     (setq ans
-	  (cond ((and (not (atom pat)) (member (caar pat) '(mnot mand mor) :test #'eq))
-		 (cond ((eq 'mnot (caar pat)) (is-mnot (cadr pat)))
-		       ((eq 'mand (caar pat)) (is-mand (cdr pat)))
-		       (t (is-mor (cdr pat)))))
-		((atom (setq patevalled (meval pat))) patevalled)
-		((member (caar patevalled) '(mnot mand mor) :test #'eq) (mevalp1 patevalled))
-		(t (mevalp2 patevalled (caar patevalled) (cadr patevalled) (caddr patevalled)))))
+          (cond ((and (not (atom pat))
+                      (member (caar pat) '(mnot mand mor) :test #'eq))
+                 (cond ((eq 'mnot (caar pat)) (is-mnot (cadr pat)))
+                       ((eq 'mand (caar pat)) (is-mand (cdr pat)))
+                       (t (is-mor (cdr pat)))))
+                ((atom (setq patevalled (specrepcheck (meval pat))))
+                 patevalled)
+                ((member (caar patevalled) '(mnot mand mor) :test #'eq)
+                 (mevalp1 patevalled))
+                (t
+                 (mevalp2 patevalled
+                          (caar patevalled)
+                          (cadr patevalled)
+                          (caddr patevalled)))))
     (list ans patevalled)))
 
 (defmfun mevalp2 (patevalled pred arg1 arg2)
@@ -957,7 +964,7 @@ relational knowledge is contained in the default context GLOBAL.")
     (cond ((eq '$zero sgn) t)
 	  ((memq sgn '($pos $neg $pn)) nil)
 
-	  ((and (memq sgn '($complex $imaginary)) (linearp z '$%i))
+	  ((memq sgn '($complex $imaginary)) ;; previously checked also for (linearp z '$%i))
 	   (setq rsgn ($csign ($realpart z)))
 	   (setq isgn ($csign ($imagpart z)))
 	   (cond ((and (eq '$zero rsgn) (eq '$zero isgn)) t)
@@ -1360,7 +1367,70 @@ relational knowledge is contained in the default context GLOBAL.")
     (when sgn (setq sign sgn minus nil odds nil evens nil)
 	  t)))
 
+;;; Look for symbols with an assumption a > n or a < -n, where n is a number.
+;;; For this case shift the symbol a -> a+n in a summation and multiplication.
+;;; This handles cases like a>1 and b>1 gives sign(a+b-2) -> pos.
+
+(defun sign-shift (expr)
+  (do ((l (cdr expr) (cdr l))
+       (fl nil)
+       (acc nil))
+      ((null l) (addn acc nil))
+    (cond ((symbolp (car l))
+           ;; Get the facts related to the symbol (car l)
+           ;; Reverse the order to test the newest facts first.
+           (setq fl (reverse (cdr (facts1 (car l)))))
+           (push (car l) acc)
+           (dolist (f fl)
+             (cond ((and (eq (caar f) 'mgreaterp)
+                         (mnump (caddr f))
+                         (eq ($sign (caddr f)) '$pos))
+                    ;; The case a > n, where a is a symbol and n a number.
+                    ;; Add the number to the list of terms.
+                    (return (push (caddr f) acc)))
+                   ((and (eq (caar f) 'mgreaterp)
+                         (mnump (cadr f))
+                         (eq ($sign (cadr f)) '$neg))
+                    ;; The case a < -n, where a is a symbol and n a number.
+                    ;; Add the number to the list of terms.
+                    (return (push (cadr f) acc))))))
+          ((mtimesp (car l))
+           (let ((acctimes) (flag))
+             ;; Go through the factors of the multiplication.
+             (dolist (ll (cdar l))
+               (cond ((symbolp ll)
+                      ;; Get the facts related to the symbol (car l)
+                      ;; Reverse the order to test the newest facts first.
+                      (setq fl (reverse (cdr (facts1 ll))))
+                      (dolist (f fl)
+                        (cond ((and (eq (caar f) 'mgreaterp)
+                                    (mnump (caddr f))
+                                    (eq ($sign (caddr f)) '$pos))
+                               ;; The case a > n, where a is a symbol and n a
+                               ;; number. Add the number to the list of terms.
+                               (setq flag t)
+                               (return (push (add ll (caddr f)) acctimes)))
+                              ((and (eq (caar f) 'mgreaterp)
+                                    (mnump (cadr f))
+                                    (eq ($sign (cadr f)) '$neg))
+                               ;; The case a < -n, where a is a symbol and n a
+                               ;; number. Add the number to the list of terms.
+                               (setq flag t)
+                               (return (push (add ll (cadr f)) acctimes)))))
+                        (when (not flag) (push ll acctimes)))
+                     (t
+                      (push ll acctimes))))
+             (if flag
+                 ;; If a shift has been done expand the factors.
+                 (push ($multthru (muln acctimes nil)) acc)
+                 (push (muln acctimes nil) acc))))
+          (t
+           (push (car l) acc)))))
+
 (defun signsum (x)
+  (setq x (sign-shift x))
+  ;; x might be simplified to an atom in sign-shift.
+  (when (atom x) (setq x (cons '(mplus) (list x))))
   (do ((l (cdr x) (cdr l)) (s '$zero))
       ((null l) (setq sign s minus nil odds (list x) evens nil)
        (cond (*complexsign*
@@ -1676,17 +1746,31 @@ relational knowledge is contained in the default context GLOBAL.")
          (merror 
            (intl:gettext "featurep: second argument must be a symbol; found ~M")
           ind))
-	((eq ind '$integer) (maxima-integerp e))
-	((eq ind '$noninteger) (nonintegerp e))
-	((eq ind '$even) (mevenp e))
-	((eq ind '$odd) (moddp e))
-	((eq ind '$real)
-	 (if (atom e)
-	     (or (numberp e) (kindp e '$real) (numberp (numer e)))
-	     (free ($rectform e) '$%i)))
-; Symbols and expressions are no longer by default complex (DK 10/2009).
-;	((eq ind '$complex) t)
-	((symbolp e) (kindp e ind))))
+        ;; Properties not related to the assume database.
+        ((and (member ind opers) (get e ind)))
+        ((and (member ind '($evfun $evflag $bindtest $special $nonarray))
+              (get e (stripdollar ind))))
+        ((and (eq ind '$noun)
+              (get e (stripdollar ind))
+              t))
+        ((and (member ind '($scalar $nonscalar $mainvar))
+              (mget e ind)))
+        ((and (eq ind '$feature)
+              (member e $features)
+              t))
+        ((eq ind '$alphabetic)
+         (dolist (l (coerce e 'list) t)
+           (when (not (member l *alphabet*)) (return nil))))
+        ;; Properties related to the assume database.
+        ((eq ind '$integer) (maxima-integerp e))
+        ((eq ind '$noninteger) (nonintegerp e))
+        ((eq ind '$even) (mevenp e))
+        ((eq ind '$odd) (moddp e))
+        ((eq ind '$real)
+         (if (atom e)
+             (or (numberp e) (kindp e '$real) (numberp (numer e)))
+             (free ($rectform e) '$%i)))
+        ((symbolp e) (kindp e ind))))
 
 ;; Give a function the maps-integers-to-integers property when it is integer
 ;; valued on the integers; give it the integer-valued property when its
@@ -2296,6 +2380,12 @@ relational knowledge is contained in the default context GLOBAL.")
 	  (kind %coth $oddfun)
 	  (kind %csch $oddfun)
 	  (kind %sech $posfun)
+	  (kind %asinh $increasing) (kind %asinh $oddfun)
+	  ;; It would be nice to say %acosh is $posfun, but then
+	  ;; assume(xn<0); abs(acosh(xn)) -> acosh(xn), which is wrong
+	  ;; since acosh(xn) is complex.
+	  (kind %acosh $increasing)
+	  (kind %atanh $increasing) (kind %atanh $oddfun)
 	  (kind $li $complex)
 	  (kind $lambert_w $complex)
 	  (kind %cabs $complex)))
