@@ -23,6 +23,10 @@
 (defvar $gamma_expand nil
   "Expand gamma(z+n) for n an integer when T.") 
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the plog function
+
 (defmfun simpplog (x vestigial z)
   (declare (ignore vestigial))
   (prog (varlist dd check y)
@@ -34,7 +38,10 @@
 	    (return (eqtest (list '(%plog) x) check))))
      (newvar x)
      (cond
-       ((and (eq '$%i (car varlist)) (not (some #'atom (cdr varlist))))
+       ((and (member '$%i varlist)
+	     (not (some #'(lambda (v)
+			    (and (atom v) (not (eq v '$%i))))
+			varlist)))
 	(setq dd (trisplit x))
 	(cond ((setq z (patan (car dd) (cdr dd)))
 	       (return (add2* (simpln (list '(%log) 
@@ -108,7 +115,18 @@
 		     ((alike1 r '((mexpt) 3 ((rat) -1 2)))
 		      (archk a b (list '(mtimes) '((rat) 1 6) '$%pi))))))))
 
-(defmfun simpbinocoef (x vestigial z) 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the Binomial coefficient
+
+;; Verb function for the Binomial coefficient
+(defun $binomial (x y)
+  (simplify (list '(%binomial) x y)))
+
+;; Binomial has Mirror symmetry
+(defprop %binomial t commutes-with-conjugate)
+
+(defun simpbinocoef (x vestigial z)
   (declare (ignore vestigial))
   (twoargcheck x)
   (let ((u (simpcheck (cadr x) z))
@@ -116,13 +134,32 @@
 	(y))
     (cond ((integerp v)
 	   (cond ((minusp v)
-		  (if (and (integerp u) (minusp u) (< v u)) (bincomp u (- u v)) 0))
+		  (if (and (integerp u) (minusp u) (< v u))
+		      (bincomp u (- u v))
+		      0))
 		 ((or (zerop v) (equal u v)) 1)
-		 ((and (integerp u) (not (minusp u))) (bincomp u (min v (- u v))))
+		 ((and (integerp u) (not (minusp u)))
+		  (bincomp u (min v (- u v))))
 		 (t (bincomp u v))))
-	  ((integerp (setq y (sub u v))) (bincomp u y))
-	  ((and (floatp u) (floatp v)) ($makegamma (list '(%binomial) u v)))
-	  (t (eqtest (list '(%binomial) u v) x)))))
+          ((integerp (setq y (sub u v)))
+           (cond ((zerop1 y)
+                  ;; u and v are equal, simplify not if argument can be negative
+                  (if (member ($csign u) '($pnz $pn $neg $nz))
+                      (eqtest (list '(%binomial) u v) x)
+                      (bincomp u y)))
+                 (t (bincomp u y))))
+          ((complex-float-numerical-eval-p u v)
+           ;; Numercial evaluation for real and complex floating point numbers.
+           (let (($numer t) ($float t))
+             ($rectform
+               ($float 
+                 ($makegamma (list '(%binomial) ($float u) ($float v)))))))
+          ((complex-bigfloat-numerical-eval-p u v)
+           ;; Numerical evaluation for real and complex bigfloat numbers.
+           ($rectform
+             ($bfloat
+               ($makegamma (list '(%binomial) ($bfloat u) ($bfloat v))))))
+          (t (eqtest (list '(%binomial) u v) x)))))
 
 (defun bincomp (u v) 
   (cond ((minusp v) 0)
@@ -143,11 +180,15 @@
      (setq u (addk -1 u) v (1- v))
      (go loop)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the Beta function
+
 (declare-top (special $numer $gammalim))
 
 (defmvar $beta_args_sum_to_integer nil)
 
-;;; The Beta funtion has mirror symmetry
+;;; The Beta function has mirror symmetry
 (defprop $beta t commutes-with-conjugate)
 
 (defmfun simpbeta (x vestigial z &aux check)
@@ -156,7 +197,11 @@
   (setq check x)
   (let ((u (simpcheck (cadr x) z)) (v (simpcheck (caddr x) z)))
     (cond ((or (zerop1 u) (zerop1 v))
-	   (if errorsw (throw 'errorsw t) (merror (intl:gettext "beta: expected nonzero arguments; found ~M, ~M") u v)))
+           (if errorsw 
+               (throw 'errorsw t) 
+               (merror 
+                 (intl:gettext "beta: expected nonzero arguments; found ~M, ~M")
+                               u v)))
 
           ;; Check for numerical evaluation in float precision
       	  ((complex-float-numerical-eval-p u v)
@@ -273,13 +318,13 @@
 				(1- x)))
 		   `((%sin) ((mtimes) ,w $%pi)))))
           
-          ((and $beta_expand (mplusp u))
+          ((and $beta_expand (mplusp u) (integerp (cadr u)))
            ;; Expand beta(a+n,b) where n is an integer.
            (let ((n (cadr u))
                  (u (simplify (cons '(mplus) (cddr u)))))
              (beta-expand-add-integer n u v)))
           
-          ((and $beta_expand (mplusp v))
+          ((and $beta_expand (mplusp v) (integerp (cadr v)))
            ;; Expand beta(a,b+n) where n is an integer.
            (let ((n (cadr v))
                  (v (simplify (cons '(mplus) (cddr v)))))
@@ -310,6 +355,10 @@
            (power (simplify (list '($pochhammer) (add u n) (- n))) -1)
            (simplify (list '($beta) u v)))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;;; Implementation of the Gamma function
+
 (defmfun simpgamma (x vestigial z)
   (declare (ignore vestigial))
   (oneargcheck x)
@@ -344,6 +393,7 @@
 			    (+ $fpprec 4))))
 	     (add (bigfloatp ($realpart result))
 		  (mul '$%i (bigfloatp ($imagpart result))))))
+          ((taylorize (mop x) (cadr x)))
           ((eq j '$inf) '$inf) ; Simplify to $inf to be more consistent.
           ((and $gamma_expand
                 (mplusp j) 
