@@ -659,18 +659,18 @@
 				      (degvector nil 1 (car subval)))))))
      (setq subval nil)
      (setq p poly)
-     (cond ((null val1)
-	    (setq subvar1 ovarlist)
-	    (setq subval1 (polysubst (nzeros (length subvar1) nil) subvar1))
-	    (go tag)))
+     (when (null val1)
+       (setq subvar1 ovarlist)
+       (setq subval1 (polysubst (make-list (length subvar1) :initial-element 0) subvar1))
+       (go tag))
      (fixvl val1 ovarlist)
      (fixvl1 val1 ovarlist)
-     (cond (subval1 (setq subval1 (polysubst subval1 subvar1))))
+     (when subval1 (setq subval1 (polysubst subval1 subvar1)))
      (setq subval (polysubst (completevector nil 0 (length subval) 1) subvar))
      tag  (fixvl subval1 subvar1)
      (setq subval1 nil subvar1 nil)
      (fixvl0 subvar subval (reverse ovarlist))
-     (cond (algfac* (setq genvar (cons (car alpha) genvar))))
+     (when algfac* (push (car alpha) genvar))
      (setq poly (cpber3 poly p))
      (setq genvar origenvar)
      (return poly)))
