@@ -74,7 +74,7 @@
       ;;loses if the argl could not be evaluated but macsyma &quote functions
       ;;but the translator should be fixed so that if (mget f 'mfexprp) is t
       ;;then it doesn't translate as an mfunction-call.
-      `(lispm-mfunction-call-aux ,f ',argl (list ,@ argl) nil)))
+      `(lispm-mfunction-call-aux ',f ',argl (list ,@ argl) nil)))
 
 (defun lispm-mfunction-call-aux (f argl list-argl autoloaded-already? &aux f-prop)
   (cond ((functionp f)
@@ -89,7 +89,7 @@
 		(mfunction-call-warn f 'mfexpr)
 		(meval (cons (list f) argl)))
 	       (t
-		(mlambda f-prop list-argl f nil nil))))
+		(mlambda f-prop list-argl f t nil))))
 	((setq f-prop (get f 'autoload))
 	 (cond (autoloaded-already?
 		(merror (intl:gettext "apply: function ~:@M undefined after loading file ~A") f (namestring (get f 'autoload))))
@@ -167,6 +167,3 @@
 			      (push res *fcall-memory*))))
     (putprop (cadr res) (mapcar #'eval (car args)) 'sumarg-env)
     (caddr res)))
-
-(defquote m-tlambda-i (&rest args)
-  `(lambda ,@(cddr args)))
