@@ -386,7 +386,7 @@ One extra decimal digit in actual representation for rounding purposes.")
 	       x))
 	  ((eq (caar x) 'mexpt)
 	   (if (equal (cadr x) '$%e)
-	       (*fpexp (caddr x))
+	       (*fpexp ($bfloat (caddr x)))
 	       (exptbigfloat ($bfloat (cadr x)) (caddr x))))
 	  ((eq (caar x) 'mncexpt)
 	   (list '(mncexpt) ($bfloat (cadr x)) (caddr x)))
