@@ -775,9 +775,9 @@ is not included")
 (defun fsqrt (x)
   (typecase x
     (single-float
-     (sqrt (the (single-float 0f0) x)))
+     (sqrt (the (or (single-float (0f0)) (member 0f0)) x)))
     (double-float
-     (sqrt (the (double-float 0d0) x)))
+     (sqrt (the (or (double-float (0d0)) (member 0d0)) x)))
     (t
      (sqrt x))))
 
@@ -1226,7 +1226,9 @@ causing all pending operations to be flushed"
 	   (arg-list
 	    (apply #'append
 		   (map 'list #'(lambda (x)
-				  (cond ((numberp x)
+				  (cond ((or (numberp x)
+					     (typep x 'bigfloat:bigfloat)
+					     (typep x 'bigfloat:complex-bigfloat))
 					 (list x))
 					((stringp x)
 					 (list x))
@@ -1465,8 +1467,17 @@ causing all pending operations to be flushed"
 ;;;-------------------------------------------------------------------------
 ;;; end of macros.l
 ;;;
-;;; $Id: f2cl-lib.lisp,v 1.20 2009/01/08 18:25:34 rtoy Exp $
+;;; $Id: f2cl-lib.lisp,v 1.22 2010/12/28 00:05:02 rtoy Exp $
 ;;; $Log: f2cl-lib.lisp,v $
+;;; Revision 1.22  2010/12/28 00:05:02  rtoy
+;;; Assert the type of the arg to fsqrt to be non-negative, excluding
+;;; negative zero.
+;;;
+;;; Revision 1.21  2010/10/16 15:24:09  rtoy
+;;; Allow f2cl-lib to recognize BIGFLOAT and COMPLEX-BIGFLOAT numbers so
+;;; that they can at least be printed, if not quite in the format
+;;; specified by the format string.
+;;;
 ;;; Revision 1.20  2009/01/08 18:25:34  rtoy
 ;;; Update f2cl to latest version of f2cl, and regenerate all of the lisp
 ;;; code.
