@@ -107,6 +107,8 @@
 	       ((eq (caar e) 'mexpt) '|$Expt|)
 	       ((eq (caar e) 'mquotient) '|$Quotient|)
 	       ((eq (caar e) 'mminus) '|$Negterm|)
+	       ((eq (caar e) 'mlist)
+	        (cons '(|$List| simp) (ncons (length (cdr e)))))
 	       (t (getop (mop e)))))
 	(t (let ((u (cond ((member 'simp (cdar e) :test #'eq) (car e))
 			  (t (cons (caar e) (cons 'simp (cdar e))))))
@@ -493,7 +495,7 @@
 (defmfun $factorout (e &rest vl)
   (prog (el fl cl l f x)
      (when (null vl)
-       (merror "`factorout' called on only one argument"))
+       (merror (intl:gettext "factorout: at least two arguments required.")))
      (unless (mplusp e)
        (return e))
      (or (null vl) (mplusp e) (return e))
