@@ -132,7 +132,7 @@
 	((eq $gcd '$red) (list (oldgcd x y)))
 	((eq $gcd '$mod) (newgcd x y modulus))
 	((not (member $gcd *gcdl* :test #'eq))
-	 (merror "`gcd' set incorrectly:~%~M" $gcd))
+	 (merror (intl:gettext "gcd: 'gcd' variable must be one of ~M; found: ~M") *gcdl* $gcd))
 	(t (list 1 x y))))
 
 (defun monomgcdco (p q cofac?)
@@ -205,7 +205,7 @@
   (setq s (case $gcd
 	    ($red (redgcd u v))
 	    ($subres (subresgcd u v))
-	    (t (merror "Illegal `gcd' algorithm"))))
+	    (t (merror "OLDGCD: found gcd = ~M; how did that happen?" gcd))))
   (let ((errrjfflag t))			;; check for gcd that simplifies to 0
     (if (not (catch 'raterr (rainv s))) ;; sourceforge bugs 831445 and 1313987
 	(setq s 1)))
@@ -266,7 +266,7 @@
 
 (defun psquorem1 (u v quop)
   (prog (k (m 0) lcu lcv quo lc)
-     (declare (special k lcu lcv))
+     (declare (special lcu lcv))
      (setq lcv (pt-lc v))
      (setq k (- (pt-le u) (pt-le v)))
      (cond ((minusp k) (return (list 1 '(0 0) u))))
@@ -274,7 +274,7 @@
      a     (setq lcu (pminus (pt-lc u)))
      (if quop (setq quo (cons (ptimes (pt-lc u) (pexpt (pt-lc v) k))
 			      (cons k quo))))
-     (cond ((null (setq u (pgcd2 (pt-red u) (pt-red v))))
+     (cond ((null (setq u (pgcd2 (pt-red u) (pt-red v) k)))
 	    (return (list lc (nreverse quo) '(0 0))))
 	   ((minusp (setq m (- (pt-le u) (pt-le v))))
 	    (setq u (cond ((zerop k) u)
@@ -292,17 +292,17 @@
 
 (defmfun pgcd1 (u v) (caddr (psquorem1 u v nil)))
 
-(defun pgcd2 (u v &aux (i 0))
-  (declare (special k lcu lcv) (fixnum k i))
+(defun pgcd2 (u v k &aux (i 0))
+  (declare (special lcu lcv) (fixnum k i))
   (cond ((null u) (pcetimes1 v k lcu))
 	((null v) (pctimes1 lcv u))
 	((zerop (setq i (+ (pt-le u) (- k) (- (car v)))))
 	 (pcoefadd (pt-le u) (pplus (ptimes lcv (pt-lc u))
 				    (ptimes lcu (pt-lc v)))
-		   (pgcd2 (pt-red u) (pt-red v))))
+                   (pgcd2 (pt-red u) (pt-red v) k)))
 	((minusp i)
-	 (list* (+ (pt-le v) k) (ptimes lcu (pt-lc v)) (pgcd2 u (pt-red v))))
-	(t (list* (pt-le u) (ptimes lcv (pt-lc u)) (pgcd2 (pt-red u) v)))))
+         (list* (+ (pt-le v) k) (ptimes lcu (pt-lc v)) (pgcd2 u (pt-red v) k)))
+        (t (list* (pt-le u) (ptimes lcv (pt-lc u)) (pgcd2 (pt-red u) v k)))))
 
 ;;;*** OLDCONTENT REMOVES ALL BUT MAIN VARIABLE AND PUTS THAT IN CONTENT
 ;;;***  OLDCONTENT OF 3*A*X IS 3*A (WITH MAINVAR=X)
@@ -389,22 +389,22 @@
 
 (defun pmodrem (x y)
   (cond ((null modulus)
-	 (merror "Illegal use of `pmodrem'"))
+	 (merror "PMODREM: null modulus; how did that happen?"))
 	((pacoefp y) (if (pzerop y) x 0))
 	((pacoefp x) x)
 	((eq (p-var x) (p-var y))
 	 (psimp (car x) (pgcdu1 (p-terms x) (p-terms y) nil)))
-	(t (merror "Illegal use of `pmodrem'"))))
+	(t (merror "PMODREM: I can't handle this; x = ~M, y = ~M" x y))))
 
 (defun pmodquo (u v &aux quo)
   (declare (special quo))
   (cond ((null modulus)
-	 (merror "Illegal use of `pmodquo'"))
+	 (merror "PMODQUO: null modulus; how did that happen?"))
 	((pcoefp v) (cons (ptimes (crecip v) u) 0))
 	((alg v) (cons (ptimes (painvmod v) u) 0))
 	((pacoefp u) (cons 0 u))
 	((not (eq (p-var u) (p-var v)))
-	 (merror "Illegal use of `pmodquo'"))
+	 (merror "PMODQUO: arguments have different variables; how did that happen?"))
 	(t (xcons (psimp (car u) (pgcdu1 (cdr u) (cdr v) t))
 		  (psimp (car u) quo)))))
 
@@ -427,7 +427,7 @@
 (defmfun $jacobi (p q)
   (cond ((null (and (integerp p) (integerp q)))
 	 (list '($jacobi) p q))
-	((zerop q) (merror "Zero denominator?"))
+	((zerop q) (merror (intl:gettext "jacobi: zero denominator.")))
 	((minusp q) ($jacobi p (- q)))
 	((and (evenp (setq q (rtzerl2 q)))
 	      (setq q (ash q -1))
