@@ -63,14 +63,24 @@
 (defprop mrat mrateval mfexpr*)
 
 (defmfun $ratnumer (x)
-  (setq x (taychk2rat x)) (cons (car x) (cons (cadr x) 1)))
+  (cond ((mbagp x)
+         (cons (car x) (mapcar '$ratnumer (cdr x))))
+        (t
+         (setq x (taychk2rat x))
+         (cons (car x) (cons (cadr x) 1)))))
 
 (defmfun $ratdenom (x)
-  (setq x (taychk2rat x)) (cons (car x) (cons (cddr x) 1)))
+  (cond ((mbagp x)
+         (cons (car x) (mapcar '$ratdenom (cdr x))))
+        (t
+         (setq x (taychk2rat x))
+         (cons (car x) (cons (cddr x) 1)))))
 
 (defun taychk2rat (x)
-  (cond ((and ($ratp x) (member 'trunc (cdar x) :test #'eq)) ($taytorat x)) (t (ratf x))))
-
+  (cond ((and ($ratp x)
+              (member 'trunc (cdar x) :test #'eq))
+         ($taytorat x))
+        (t ($rat x))))
 
 (defmvar tellratlist nil)
 
@@ -100,10 +110,10 @@
   (setq x ($totaldisrep x))
   (and (not (atom x)) (eq (caar x) 'mequal) (newvar (cadr x)))
   (newvar (setq x (meqhk x)))
-  (unless varlist (merror "Improper polynomial"))
+  (unless varlist (merror (intl:gettext "tellrat: argument must be a polynomial; found: ~M") x))
   (setq algvar (car (last varlist)))
   (setq x (p-terms (primpart (cadr (ratrep* x)))))
-  (unless (equal (pt-lc x) 1) (merror "Minimal polynomial must be monic"))
+  (unless (equal (pt-lc x) 1) (merror (intl:gettext "tellrat: minimal polynomial must be monic.")))
   (do ((p (pt-red x) (pt-red p)))
       ((ptzerop p))
     (setf (pt-lc p) (pdis (pt-lc p))))
@@ -141,6 +151,9 @@
 
 (defun fullratsimp (l)
   (let (($expop 0) ($expon 0) (inratsimp t) $ratsimpexpons)
+    (when (not ($ratp l))
+      ;; Not a mrat expression. Remove the special representation.
+      (setq l (specrepcheck l)))
     (setq l ($totaldisrep l))
     (fr1 l varlist)))
 
@@ -278,7 +291,7 @@
 		(when (or (pcoefp minpoly*)
 			  (not (univar (cdr minpoly*)))
 			  (< (cadr minpoly*) 2))
-		  (merror "The second argument to `factor' must be a non-linear, univariate polynomial: ~M" alpha))
+		  (merror (intl:gettext "factor: second argument must be a nonlinear, univariate polynomial; found: ~M") alpha))
 		(setq alpha (pdis (list (car minpoly*) 1 1))
 		      mm* (cadr minpoly*))
 		(unless (equal (caddr minpoly*) 1)
@@ -349,7 +362,7 @@
     (when m?
       (setq modulus m)
       (when (or (not (integerp modulus)) (zerop modulus))
-	(merror "Improper value for `modulus':~%~M" modulus)))
+	(merror (intl:gettext "polymod: modulus must be a nonzero integer; found: ~M") modulus)))
     (when (minusp modulus)
       (setq modulus (abs modulus)))
     (mod1 p)))
@@ -545,7 +558,7 @@
 (defun rget (genv)
   (cons (if (and $ratwtlvl
 		 (or (fixnump $ratwtlvl)
-		     (merror "Illegal value for `ratwtlvl':~%~M" $ratwtlvl))
+		     (merror (intl:gettext "rat: 'ratwtlvl' must be an integer; found: ~M") $ratwtlvl))
 		 (> (or (get genv '$ratweight) -1) $ratwtlvl))
 	    (pzero)
 	    (pget genv))
@@ -890,8 +903,8 @@
 		  (cons num den))))))))
 
 (defun prepfloat (f)
-  (cond (modulus (merror "Floating point meaningless unless `modulus' = `false'"))
-	($ratprint (mtell "~&rat: replaced ~A by" f)))
+  (cond (modulus (merror (intl:gettext "rat: can't rationalize ~M when modulus = ~M") f modulus))
+	($ratprint (mtell (intl:gettext "~&rat: replaced ~A by") f)))
   (setq f (maxima-rationalize f))
   (when $ratprint
     (mtell " ~A/~A = ~A~%"  (car f) (cdr f) (fpcofrat1 (car f) (cdr f))))
@@ -965,12 +978,17 @@
 (defmvar $ratdenomdivide t)
 
 (defmfun $ratdisrep (x)
-  (cond ((not ($ratp x)) x)
-	(t (setq x (ratdisrepd x))
-	   (if (and (not (atom x))
-		    (member 'trunc (cdar x) :test #'eq))
-	       (cons (delete 'trunc (copy-list (car x)) :count 1 :test #'eq) (cdr x))
-	       x))))
+  (cond ((mbagp x)
+         ;; Distribute over lists, equations, and matrices.
+         (cons (car x) (mapcar #'$ratdisrep (cdr x))))
+        ((not ($ratp x)) x)
+        (t
+         (setq x (ratdisrepd x))
+         (if (and (not (atom x))
+                  (member 'trunc (cdar x) :test #'eq))
+           (cons (delete 'trunc (copy-list (car x)) :count 1 :test #'eq)
+                 (cdr x))
+           x))))
 
 ;; RATDISREPD is needed by DISPLA. - JPG
 (defun ratdisrepd (x)
