@@ -61,30 +61,6 @@
       $tr_numer
       $define_variable))
 
-(defmacro trlisp-inputname-d1 () ;; so hacks on DEFAULTF will not
-  '`,(pathname "")) ;; stray the target.
-
-(defmacro trlisp-outputname-d1 ()
-  '`,(pathname (maybe-invert-string-case (symbol-name (stripdollar $tr_output_file_default)))))
-
-(defmacro trlisp-outputname ()
-  '`,(make-pathname :type "LISP"))
-
-(defmacro trlisp-outputname-temp ()
-  '`,(pathname "_trli_"))
-
-(defmacro trtags-outputname ()
-  '`,(pathname "tags"))
-
-(defmacro trtags-outputname-temp ()
-  '`,(pathname "_tags_"))
-
-(defmacro trcomments-outputname ()
-  '`,(pathname "unlisp"))
-
-(defmacro trcomments-outputname-temp ()
-  '`,(pathname "_unli_"))
-
 (defvar declares nil)
 
 (defmspec $compfile (forms)
@@ -218,29 +194,8 @@
 		(format out-stream "~a" transl))))))
 
 
-(defun translate-from-stream (from-stream &key to-stream eval pretty (print-function #'prin1)
-			      &aux expr transl)
-  (bind-transl-state
-   (loop
-      with *in-translate-file* = t
-      with *print-pretty* = pretty
-      while (and (setq expr (mread from-stream)) (consp expr))
-      do (setq transl (translate-macexpr-toplevel (third expr)))
-      (cond (eval (eval transl)))
-      (cond (to-stream (funcall print-function transl to-stream)))
-      (loop for v in forms-to-compile-queue
-	 do (show v to-stream)
-	 when to-stream
-	 do (funcall print-function v to-stream)
-	 when eval
-	 do (eval v))
-      (setq forms-to-compile-queue nil))))
-
 (defvar trf-start-hook nil)
 
-(defun delete-old-and-open (x)
-  (open x :direction :output))
-
 (defun alter-pathname (pathname &rest options)
   (apply 'make-pathname :defaults (pathname  pathname) options))
 
@@ -398,45 +353,12 @@ translated."
     (print-module (car s))))
 
 
-(defun print-transl-header (source)
-  (mformat transl-file ";;; -*- Mode: Lisp; package:maxima; syntax:common-lisp -*-~%")
-  (if source
-      (mformat transl-file ";;; Translated code for ~A" source)
-      (mformat transl-file ";;; Translated Maxima functions generated by `compfile'."))
-  (mformat transl-file "~%;;; Written on ~:M, from Maxima ~A~%;;;~%" ($timedate) $version)
-  (print-transl-modules)
-  (mformat transl-file
-	   "~%~
-	   ~%~
-	   ~%(eval-when (:compile-toplevel :execute) ~
-	   ~%      (setq *infile-name-key*~
-	   ~%               ((lambda (file-name)~
-	   ~%                           ;; temp crock for multics.~
-	   ~%                          (cond ((eq (ml-typep file-name) 'list)~
-	   ~%                                 (namestring file-name))~
-	   ~%                                (t file-name)))~
-	   ~%                  (truename infile))))~
-	   ~%~
-	   ~%(eval-when (:compile-toplevel) ~
-	   ~%   (setq $tr_semicompile '~S)~
-	   ~%   (setq forms-to-compile-queue ()))~
-	   ~%~%;;; ~S~%~%"
-	   $tr_semicompile source)
-  (cond ($transcompile
-	 (update-global-declares)
-	 (when $compgrind
-	   (mformat transl-file ";;; General declarations required for translated Maxima code.~%"))
-	 (print* `(declare . ,declares)))))
-
 (defun print-abort-msg (fun from)
   (mformat *translation-msgs-files*
 	   "~:@M failed to Translate.~
 	    ~%~A will continue, but file output will be aborted."
 	   fun from))
 
-(defmacro extension-filename (x)
-  `(caddr (namelist ,x)))
-
 (defmspec $translate (functs)
   (setq functs (cdr functs))
   (cond ((and functs ($listp (car functs)))
