@@ -25,8 +25,8 @@
 
 ;;I think all this can be done at load time only:--wfs
 (eval-when
-    #+gcl (load)
-    #-gcl (:load-toplevel)
+    #+gcl (load eval)
+    #-gcl (:load-toplevel :execute)
 
     (mapc #'(lambda (x) (putprop x '$fixnum 'function-mode))
 	  '($length $nterms random $nroots $rank $polysign $time
