@@ -58,7 +58,7 @@
 				       (cdr e))))
 	((eq (caar e) '%integrate)
 	 (list* '(%integrate) (sp1 (cadr e)) (cddr e)))
-	(t e)))
+        (t (recur-apply #'sp1 e))))
 
 (setq trans-list-plus
       '( (((mplus) ((coeffpt) (c true) ((mexpt) ((%tan) (x true)) 2))
@@ -98,7 +98,7 @@
 		 ((equal (setq gcd ($gcd nn nd)) 1) e)
 		 ((div* (cadr ($divide nn gcd))
 			(cadr ($divide nd gcd)))))))
-	(t e)))
+        (t (recur-apply #'gcdred e))))
 
 (defun sp1times (e)
   (let* ((fr
@@ -348,7 +348,7 @@
 
 (defun sp1expt (b e)
   (cond ((mexptp b)
-	 (sp1expt (cadr b) (m* e (caddr b))))
+         (power (sp1 b) (sp1 e)))
 	((and (null (trigfp b)) (free e var))
 	 (m^ b e))
 	((equal b '$%e)
@@ -399,9 +399,10 @@
 
 (defun sp1log2 (e)
   (and $verbose
-       (prog2 (mtell "Can't expand ")
-	   (show-exp (list '(%log) e))
-	 (mtell "So we'll try again after applying the rule:~2%~M~%~%"
+       (prog2
+         (mtell "trigreduce: can't expand~%~%")
+	 (show-exp (list '(%log) e))
+	 (mtell "trigreduce: try again after applying the rule:~2%~M~%~%"
 		(list '(mlable) nil
 		      (out-of
 		       (list '(mequal)
