@@ -27,18 +27,17 @@
 (defmvar $logarc nil)
 (defmvar $halfangles nil)
 
-(defmvar 1//2 '((rat simp) 1 2))
-(defmvar -1//2 '((rat simp) -1 2))
-(defmvar %pi//4 '((mtimes simp) ((rat simp) 1 4.) $%pi))
-(defmvar %pi//2 '((mtimes simp) ((rat simp) 1 2) $%pi))
-(defmvar sqrt2//2 '((mtimes simp) ((rat simp) 1 2)
-		    ((mexpt simp) 2 ((rat simp) 1 2))))
-(defmvar -sqrt2//2 '((mtimes simp) ((rat simp) -1 2)
-		     ((mexpt simp) 2 ((rat simp) 1 2))))
-(defmvar sqrt3//2 '((mtimes simp) ((rat simp) 1 2)
-		    ((mexpt simp) 3 ((rat simp) 1 2))))
-(defmvar -sqrt3//2 '((mtimes simp) ((rat simp) -1 2)
-		     ((mexpt simp) 3 ((rat simp) 1 2))))
+;; Simplified shortcuts for constant expressions.
+(defvar 1//2 '((rat simp) 1 2))
+(defvar -1//2 '((rat simp) -1 2))
+(defvar %pi//4 '((mtimes simp) ((rat simp) 1 4.) $%pi))
+(defvar %pi//2 '((mtimes simp) ((rat simp) 1 2) $%pi))
+(defvar sqrt3//2 '((mtimes simp)
+                   ((rat simp) 1 2) 
+                   ((mexpt simp) 3 ((rat simp) 1 2))))
+(defvar -sqrt3//2 '((mtimes simp)
+                    ((rat simp) -1 2)
+                    ((mexpt simp) 3 ((rat simp) 1 2))))
 
 ;;; Arithmetic utilities.
 
@@ -271,7 +270,7 @@
 		   (let ((y (ignore-errors (maxima-branch-atanh (/ 1 x))))) 
 		     (if y y (domain-error x 'acoth)))))
 
-  (frob %mabs #'cl:abs)
+  (frob mabs #'cl:abs)
   (frob %exp #'cl:exp)
   (frob mexpt #'cl:expt)
   (frob %sqrt #'cl:sqrt)
@@ -605,16 +604,18 @@
      ;; return their quotient.
      ((and (zerop1 zl-rem)
 	   (setq sin-of-coeff-pi
-		 (%piargs coeff nil))
-	   (setq cos-of-coeff-pi
-		 (%piargs (cons (car coeff)
-				(rplus 1//2 (cdr coeff))) nil)))
-      (unless (zerop1 cos-of-coeff-pi)
-	(div sin-of-coeff-pi cos-of-coeff-pi)))
+		 (%piargs coeff nil)))
+      (setq cos-of-coeff-pi
+	    (%piargs (cons (car coeff)
+			   (rplus 1//2 (cdr coeff))) nil))
+      (cond ((zerop1 sin-of-coeff-pi) 
+	     0)		;; tan(integer*%pi)
+	    ((zerop1 cos-of-coeff-pi)
+	     (merror "~M isn't in the domain of tan" x))
+	    (cos-of-coeff-pi
+	     (div sin-of-coeff-pi cos-of-coeff-pi))))
        
-     ;; I _think_ (car coeff)=1 => the coefficient of %pi is an
-     ;; integer, but evod can't work out whether it's even or odd. In
-     ;; which case we can't do anything :( Return nil.
+     ;; Need period of 2*%pi to continue
      ((not (mevenp (car coeff))) nil)
  
      ;; This expression sets x to the coeff of %pi (mod 2) as a side
@@ -690,51 +691,59 @@
 		   ((alike1 1//2 x) (cons-exp '%sec zl-rem))
 		   ((alike1 '((rat) 3 2) x) (neg (cons-exp '%sec zl-rem)))))))
 
-(defmfun simp-%atan (form y z)
+(defun simp-%atan (form y z)
   (oneargcheck form)
   (setq y (simpcheck (cadr form) z))
   (cond ((flonum-eval (mop form) y))
-	((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
-	((taylorize (mop form) (second form)))
-	((and $%piargs
-	      ;; Recognize some special values
-	      (cond ((zerop1 y)
-		     0)
-		    ((equal 1 y)
-		     %pi//4)
-		    ((equal -1 y)
-		     (neg %pi//4))
-		    ;; sqrt(3)
-		    ((alike1 y (power* 3 1//2))
-		     (div '$%pi 3))
-		    ;; -sqrt(3)
-		    ((alike1 y (mul -1 (power* 3 1//2)))
-		     (div '$%pi -3))
-		    ;; 1/sqrt(3) = sqrt(3)/3
-		    ((or (alike1 y (power* 3 -1//2))
-			 (alike1 y (mul (rat 1 3) (power* 3 1//2))))
-		     (div '$%pi 6))
-		    ;; -1/sqrt(3) = -sqrt(3)/3
-		    ((or (alike1 y (mul -1 (power* 3 -1//2)))
-			 (alike1 y (div (power* 3 1//2) -3)))
-		     (div '$%pi -6)))))
-	((and $%iargs (multiplep y '$%i)) (mul '$%i (cons-exp '%atanh (coeff y '$%i 1))))
+        ((and (not (member 'simp (car form))) (big-float-eval (mop form) y)))
+        ((taylorize (mop form) (second form)))
+        ;; Simplification for special values
+        ((zerop1 y) y)
+        ((or (eq y '$inf) (alike1 y '((mtimes) -1 $minf)))
+         (div '$%pi 2))
+        ((or (eq y '$minf) (alike1 y '((mtimes) -1 $inf)))
+         (div '$%pi -2))
+        ((and $%piargs
+              ;; Recognize more special values
+              (cond ((equal 1 y) (div '$%pi 4))
+                    ((equal -1 y) (div '$%pi -4))
+                    ;; sqrt(3)
+                    ((alike1 y '((mexpt) 3 ((rat) 1 2)))
+                     (div '$%pi 3))
+                    ;; -sqrt(3)
+                    ((alike1 y '((mtimes) -1 ((mexpt) 3 ((rat) 1 2))))
+                     (div '$%pi -3))
+                    ;; 1/sqrt(3)
+                    ((alike1 y '((mexpt) 3 ((rat) -1 2)))
+                     (div '$%pi 6))
+                    ;; -1/sqrt(3)
+                    ((alike1 y '((mtimes) -1 ((mexpt) 3 ((rat) -1 2))))
+                     (div '$%pi -6))
+                    ((alike1 y '((mplus) -1 ((mexpt) 2 ((rat) 1 2))))
+                     (div '$%pi 8))
+                    ((alike1 y '((mplus) 1 ((mexpt) 2 ((rat) 1 2))))
+                     (mul 3 (div '$%pi 8))))))
+        ((and $%iargs (multiplep y '$%i))
+         ;; atan(%i*y) -> %i*atanh(y)
+         (mul '$%i (take '(%atanh) (coeff y '$%i 1))))
 	((and (not (atom y)) (member (caar y) '(%cot %tan))
 	      (if ($constantp (cadr y))
 		  (let ((y-val (mfuncall '$mod 
-					 (if (eq (caar y) '%tan) (cadr y) (m- %pi//2 (cadr y)))
+					 (if (eq (caar y) '%tan)
+					     (cadr y)
+					     (sub %pi//2 (cadr y)))
 					 '$%pi)))
 		    (cond ((eq (mlsp y-val %pi//2) t) y-val)
-			  ((eq (mlsp y-val '$%pi) t) (m- y-val '$%pi)))))))
+			  ((eq (mlsp y-val '$%pi) t) (sub y-val '$%pi)))))))
 	((and (eq $triginverses '$all) (not (atom y))
 	      (if (eq (caar y) '%tan) (cadr y))))
 	((and (eq $triginverses t) (not (atom y)) (eq (caar y) '%tan)
-	      (if (and (member (csign (m- (cadr y) %pi//2)) '($nz $neg) :test #'eq)
-		       (member (csign (m+ (cadr y) %pi//2)) '($pz $pos) :test #'eq))
+	      ;; Check if y in [-%pi/2, %pi/2]
+	      (if (and (member (csign (sub (cadr y) %pi//2)) '($nz $neg) :test #'eq)
+		       (member (csign (add (cadr y) %pi//2)) '($pz $pos) :test #'eq))
 		  (cadr y))))
 	($logarc (logarc '%atan y))
 	((apply-reflection-simp (mop form) y $trigsign))
-	;((and $trigsign (mminusp* y)) (neg (cons-exp '%atan (neg y))))
 	(t (eqtest (list '(%atan) y) form))))
 
 (defun %piargs (x ratcoeff)
@@ -760,6 +769,9 @@
 	((or (alike1 '((rat) 5 4) x) (alike1 '((rat) 7 4) x)) (mul -1//2 (power 2 1//2)))
 	((alike1 '((rat) 3 2) x) -1)))
 
+;; identifies integer part of form
+;; returns (X . Y) if form can be written as X*some_integer + Y
+;; returns nil otherwise
 (defun linearize (form)
   (cond ((integerp form) (cons 0 form))
 	((numberp form) nil)
