@@ -42,12 +42,6 @@
 	  ((eq '$number mode) `($number + . ,(mapcar #'cdr args)))
 	  (t `($any add* . ,(mapcar #'dconvx args))))))
 
-(defun nestify (op l)
-  (do ((l (cdr l) (cdr l))
-       (nl (car l)))
-      ((null l) nl)
-    (setq nl (list op nl (car l)))))
-
 (def%tr mtimes (form)
   (let (args mode)
     (cond ((equal -1 (cadr form))
@@ -202,11 +196,11 @@
       (cons '$float (dconv-$float form))
       `($any $float ,(cdr form))))
 
-(def%tr $exp (form)
+(def%tr %exp (form)
   (setq form (translate (cadr form)))
   (if (eq '$float (car form))
       `($float exp ,(cdr form))
-      `($any simplify ($exp ,(cdr form)))))
+      `($any simplify (list '(%exp) ,(cdr form)))))
 
 (def%tr $atan2 (form)
   (setq form (cdr form))
