@@ -32,11 +32,11 @@
 	"rtest_diff_invtrig"
 	"rtest_scalarp"
 	"rtest_everysome"
-        ((mlist simp) "rtestint" 83)
+        "rtestint"
 	"rtestifactor"
         ((mlist simp) "rtest_equal" 157 160)
 	"rtest_abs"
-	((mlist simp) "rtest_taylor" 88 91 94 96 99 118 119 120 121 123 124)
+	((mlist simp) "rtest_taylor" 88 91 94 96 99 118 119 120 121 123 124 133)
 	((mlist simp) "rtest_dot")
 	"rtest_mset"
 	"rtest_boolean"
